@@ -214,18 +214,18 @@ def run():
     if len(sys.argv) > 1 and sys.argv[1] != "-py":
         main = Main(sys.argv[1])
         if "-py" in sys.argv:
-            if not os.path.isdir('\\'.join(sys.argv[1].split("\\")[:-1]) + '\\python'):
-                os.mkdir('\\'.join(sys.argv[1].split("\\")[:-1]) + '\\python')
-            o = open('\\'.join(sys.argv[1].split("\\")[:-1]) + "\\python\\" + sys.argv[1].split("\\")[-1].split(".")[0] + ".py", "w")
+            if not os.path.isdir('\\'.join(sys.argv[1].split("\\")[:-1]) + '\\python-compiled'):
+                os.mkdir('\\'.join(sys.argv[1].split("\\")[:-1]) + '\\python-compiled')
+            o = open('\\'.join(sys.argv[1].split("\\")[:-1]) + "\\python-compiled\\" + sys.argv[1].split("\\")[-1], "w")
             o.write(main.connected)
             o.close()
     else:
         print("======================= no file entered, running example =======================\n")
-        main = Main(f"{os.path.dirname(os.path.abspath(__file__))}\\examples\\curly.pt")
+        main = Main(f"{os.path.dirname(os.path.abspath(__file__))}\\examples\\curly.py")
         if "-py" in sys.argv:
-            if not os.path.isdir(os.path.dirname(os.path.abspath(__file__)) + '\\examples\\python'):
-                os.mkdir(os.path.dirname(os.path.abspath(__file__)) + '\\examples\\python')
-            o = open(os.path.dirname(os.path.abspath(__file__)) + "\\examples\\python\\curly.py", "w")
+            if not os.path.isdir(os.path.dirname(os.path.abspath(__file__)) + '\\examples\\python-compiled'):
+                os.mkdir(os.path.dirname(os.path.abspath(__file__)) + '\\examples\\python-compiled')
+            o = open(os.path.dirname(os.path.abspath(__file__)) + "\\examples\\python-compiled\\curly.py", "w")
             o.write(main.connected)
             o.close()
 
